@@ -1,6 +1,6 @@
 ;;; mh-xemacs-compat.el --- GNU Emacs Functions needed by XEmacs
 
-;; Copyright (C) 2001, 2002 Free Software Foundation, Inc.
+;; Copyright (C) 2001, 02, 2003 Free Software Foundation, Inc.
 
 ;; Author: FSF
 ;; Maintainer: Bill Wohler <wohler@newt.com>
@@ -28,12 +28,11 @@
 
 ;;; Change Log:
 
-;; $Id: mh-xemacs-compat.el,v 1.3 2003/02/10 03:32:25 youngs Exp $
-
 ;;; Code:
 
 ;;; Some requires:
 (require 'rfc822)
+(eval-when-compile (require 'mh-utils))
 
 ;;; Simple compatibility:
 
@@ -52,6 +51,42 @@
 (unless (fboundp 'cancel-timer)
   (defalias 'cancel-timer 'delete-itimer))
 
+;; Set up the modeline glyph
+(defconst mh-modeline-logo
+  "/* XPM */
+static char * file[] = {
+\"18 13 2 1\",
+\"# c #666699\",
+\". c None s None\",
+\"........##........\",
+\".......####.......\",
+\"......######......\",
+\"......######......\",
+\"....#########.....\",
+\"..##############..\",
+\".##...######....#.\",
+\"##...#.#.####...#.\",
+\"....#..#.##.#...#.\",
+\"...#..##.#.#.#....\",
+\"...#..#..#..#.#...\",
+\"...#..#.##..#.##..\",
+\"...#..#.#..#....#.\"};"
+  "The image for the modeline logo.")
+
+(mh-do-in-xemacs
+  (defvar mh-modeline-glyph
+    (progn
+      (let* ((data mh-modeline-logo)
+             (glyph (make-glyph
+                     (cond ((and (featurep 'xpm)
+                                 (device-on-window-system-p)
+                                 has-modeline-p)
+                            `[xpm :data ,data])
+                           (t [string :data "MH-E"])))))
+        (set-glyph-face glyph 'modeline-buffer-id)
+        glyph))
+    "Cute little logo to put in the modeline of MH-E buffers."))
+
 (provide 'mh-xemacs-compat)
 
 ;;; Local Variables:
